@@ -1,10 +1,11 @@
 #!/bin/bash
 # UUID	(http://www.ossp.org/pkg/lib/uuid/)
 #	BuildScript for Plamo Linux 4.5
-#			by Jun Kuwamura <juk@linet.gr.jp> on 2008-06-30
+#			by Jun Kuwamura <juk@linet.gr.jp> on 2011-04-29
 # require:
 #
-SRC_URI=ftp://ftp.ossp.org/pkg/lib/uuid/uuid-1.6.1.tar.gz
+SRC_URI=ftp://ftp.ossp.org/pkg/lib/uuid/uuid-1.6.2.tar.gz
+SRC_URI=http://www.mirrorservice.org/sites/ftp.ossp.org/pkg/lib/uuid/uuid-1.6.2.tar.gz
 SRC_FILE=${SRC_URI##*/}
 PAC_NAME=${SRC_FILE%%.tar.gz}
 
@@ -14,8 +15,8 @@ SYS_NAME="${CPU}-${REL}"
 
 PLAMO=/expo/Build
 SRC_DIR=$PLAMO/Archive/devel
-PAC_DIR=$PLAMO/Packages/4.5/Develop
-BUILD_DIR=$PLAMO/ossp
+PAC_DIR=$PLAMO/Packages/4.7/Develop
+BUILD_DIR=$PLAMO/ossp-uuid
 CUSTOM_DIR=$BUILD_DIR/Custom
 
 echo $PAC_DIR
@@ -62,10 +63,10 @@ chmod -R a+rX $DOC_DIR
 cd $WORK
 echo "y
 1
-" | makepkg ${PAC_NAME}.tgz
+" | makepkg ${PAC_NAME}-${SYS_NAME}.tgz
 
 echo -n "$PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz"
-if `mv -v ${PAC_NAME}.tgz  $PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz 1>/dev/null 2>&1`; then
+if `mv -v ${PAC_NAME}-${SYS_NAME}.tgz  $PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz 1>/dev/null 2>&1`; then
   echo " ... done"
 else
   echo " ... false"
